/*
 * Copyright 2009 Jonathan Rubin
 * This file is part of Camus.
 *
 * Camus is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Camus is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Camus.  If not, see <http://www.gnu.org/licenses/>.
 */

import java.util.List;

import cbr.framework.Case;
import cbr.framework.CaseBase;
import cbr.framework.Reasoner;
import cbr.framework.TargetFeature;
import cbr.framework.Value;
import cbr.similarity.EuclideanDistanceMetric;
import cbr.similarity.RankSimilarityMetric;

/**
 * This file demonstrates the use CAMUS (Case Assembly, Maintenance & Usage System) as a CBR framework.
 * It uses two supplied similarity metrics and feature values.
 * Bugs, improvements, concerns can be reported to jrub001@aucklanduni.ac.nz
 * 
 * @author Jonathan Rubin
 * @version 1.0
 */
public class CBRApplication {
	public static void main(String[] args){
		
		// Assemble the case base
		final CaseBase caseBase = new CaseBase();
		final String caseFile = "games.cb";
		caseBase.assembleCaseBase(caseFile);
		
		// Create a target case 
		Case targetCase = new Case();
		targetCase.addFeature(new TargetFeature("GamesPlayed", new Value(10), new EuclideanDistanceMetric(100), 1.0));
		targetCase.addFeature(new TargetFeature("Rank", new Value('D'), new RankSimilarityMetric(), 1.0));
		
		// Retrieve the most similar source cases
		final List<Case> mostSimilarCases = Reasoner.getNMostSimilarCases(3, targetCase, caseBase);
		
		// Display the results
		printCaseInfo(mostSimilarCases);
	}
	
	private static void printCaseInfo(final List<Case> cases){
		for(final Case c : cases){
			System.out.println(c);
		}
	}
}
