/*
 * Copyright 2009 Jonathan Rubin
 * This file is part of Camus.
 *
 * Camus is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Camus is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Camus.  If not, see <http://www.gnu.org/licenses/>.
 */

package cbr.framework;

/**
 * <p>A feature is an attribute value pair. Features can have a weight value and each must
 * specify a similarity metric to be used to compare features.</p> 
 *
 */
public class Feature {
	private String name;
	private Value value;
	private boolean indexed;
	
	/**
	 * Creates a <code>Feature</code> by supplying a name and value and indicating whether the <code>feature</code> is indexed or not.
	 * @param name the name of the <code>feature</code> 
	 * @param value the value of the <code>feature</code>
	 * @param indexed true if the <code>feature</code> is indexed, otherwise false
	 */
	public Feature(final String name, final Value value, final boolean indexed){
		this.name = name;
		this.value = value;
		this.indexed = indexed;
	}
	
	/**
	 * Get the name of the <code>feature</code>
	 * @return the name of the <code>feature</code>
	 */
	public String getName() {
		return name;
	}

	/**
	 * Returns the value of this feature, represented as a <code>String</code>.
	 * @return a <code>String</code> representing the value
	 */
	public String getValueAsString() {
		return value.getValue();
	}
	
	/**
	 * Returns whether the feature is indexed or not 
	 * @return true if indexed, false if not indexed
	 */
	public boolean isIndexed(){
		return indexed;
	}
	
	/**
	 * Describes the current state of this <code>Feature</code>
	 * @return a <code>String</code> describing this feature
	 */
	@Override
	public String toString(){
		return name + ": " + getValueAsString();
	}
}
