/*
 * Copyright 2009 Jonathan Rubin
 * This file is part of Camus.
 *
 * Camus is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Camus is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Camus.  If not, see <http://www.gnu.org/licenses/>.
 */

package cbr.framework;

/**
 * <p>This class provides information about the final outcome that resulted from applying a
 * <code>Solution</code> to a <code>Case</code>. The Outcome is a numerical measure of a Case's success.</p> 
 *
 */
public class Outcome {
	private double value;
	
	/**
	 * Default constructor. Sets the <code>Outcomes</code> value to 0.
	 */
	public Outcome(){
		value = 0.0;
	}
	
	/**
	 * Value-supplied Constructor. Sets the <code>Outcomes</code> value to the <code>value</code> supplied.
	 * @param value the outcomes value
	 */
	public Outcome(final double value){
		this.value = value;
	}
	
	/**
	 * Get the value of the outcome.
	 * @return the value of the outcome
	 */
	public double getValue(){
		return value;
	}
	
	/**
	 * Set the outcome value.
	 * @param value the outcome value
	 */
	public void setValue(final double value){
		this.value = value;
	}
}
