/*
 * Copyright 2009 Jonathan Rubin
 * This file is part of Camus.
 *
 * Camus is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Camus is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Camus.  If not, see <http://www.gnu.org/licenses/>.
 */

package cbr.framework;

/**
 * <p>When a user defines a similarity metric they will need to implement this interface.</p>  
 *
 */
public interface SimilarityMetric {
	/**
	 * Users will need to override this method to perform some meaningful comparison between two features.
	 * @param f1 a case feature
	 * @param f2 another case feature
	 * @return the similarity of these two features represented as a double. 1.0 is entirely similar, whereas 0.0 is entirely dissimilar.
	 */
	public double compare(final Feature f1, final Feature f2);
}
