/*
 * Copyright 2009 Jonathan Rubin
 * This file is part of Camus.
 *
 * Camus is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Camus is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Camus.  If not, see <http://www.gnu.org/licenses/>.
 */

package cbr.framework;

/**
 * <p>A <code>value</code> simply stores a <code>String</code>. It is up to the user to create a <code>SimilarityMetric</code>
 * to do something useful with the <code>Value</code><p>
 *
 */
public class Value {
	private String value;
	
	/**
	 * Create a <code>value</code> given a <code>String</code>. 
	 * @param value a <code>String</code> representing the value
	 */
	public Value(final String value){
		this.value = value;
	}
	
	/**
	 * Create a <code>value</code> given a <code>double</code>. 
	 * @param value a <code>double</code> representing the value
	 */
	public Value(final double value){
		this.value = value + "";
	}
	
	/**
	 * Create a <code>value</code> given an <code>int</code>. 
	 * @param value an <code>int</code> representing the value
	 */
	public Value(final int value){
		this.value = value + "";
	}
	
	/**
	 * Create a <code>value</code> given a <code>char</code>.
	 * @param value a <code>char</code> representing the value
	 */
	public Value(final char value){
		this.value = value + "";
	}
	
	/**
	 * Create a <code>value</code> given a <code>boolean</code>. 
	 * @param value a <code>boolean</code> representing the value
	 */
	public Value(final boolean value){
		if(value){
			this.value = "true";
		} else {
			this.value = "false";
		}
	}
	
	/**
	 * Getter method for the <code>String</code> value.
	 * @return the value as a <code>String</code>
	 */
	public String getValue(){
		return value;
	}
}
