/*
 * Copyright 2009 Jonathan Rubin
 * This file is part of Camus.
 *
 * Camus is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Camus is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Camus.  If not, see <http://www.gnu.org/licenses/>.
 */

package cbr.similarity;

import cbr.framework.Feature;
import cbr.framework.SimilarityMetric;

/**
 * Very simple similarity metric that compares two alphabetical feature values
 * Returns 1.0 if the characters are the same, otherwise returns 0.0 is they are different
 *
 */
public class RankSimilarityMetric implements SimilarityMetric {
	
	/**
	 * Compares two characters and assigns a similarity value.
	 * @param f1 a feature that holds a character as it's value
	 * @param f2 a feature that holds a character as it's value
	 * @return double Returns 1.0 if the characters are the same, otherwise returns 0.0 is they are different
	 */
	@Override
	public double compare(Feature f1, Feature f2) {
		char value1 = f1.getValueAsString().charAt(0);
		char value2 = f2.getValueAsString().charAt(0);
		
		if(value1 == value2){
			return 1.0;
		} else {
			return 0.0;
		}
	}

}
